Package: genArise
Version: 1.89.0
Title: Microarray Analysis tool
Author: Ana Patricia Gomez Mayen <pgomez@ifc.unam.mx>,\\ Gustavo
        Corral Guille <gcorral@ifc.unam.mx>, \\ Lina Riego Ruiz
        <lriego@ifc.unam.mx>,\\ Gerardo Coello Coutino
        <gcoello@ifc.unam.mx>
Acknowledgements: Jorge Ramirez Salcedo and Microarray Unit IFC
Maintainer: IFC Development Team <info-genarise@ifc.unam.mx>
Depends: R (>= 1.7.1), locfit, tkrplot, methods
Imports: graphics, grDevices, methods, stats, tcltk, utils, xtable
Description: genArise is an easy to use tool for dual color microarray
        data. Its GUI-Tk based environment let any non-experienced
        user performs a basic, but not simple, data analysis just
        following a wizard. In addition it provides some tools for the
        developer.
biocViews: Microarray, TwoChannel, Preprocessing
License: file LICENSE
License_restricts_use: yes
URL: http://www.ifc.unam.mx/genarise
git_url: https://git.bioconductor.org/packages/genArise
git_branch: devel
git_last_commit: fcaf847
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 22:07:10 UTC; biocbuild
Built: R 4.6.0; ; 2026-05-19 04:52:37 UTC; unix
