\name{set.project.properties}
\alias{set.project.properties}
\title{set.project.properties}
\description{
Auxiliar function for genAriseGUI
}
\usage{
set.project.properties(envir)
}
\arguments{
\item{envir}{Environment where are the experiment variables}
}
\keyword{arith}