\name{back.gui}
\alias{back.gui}
\title{Return to the last window}
\description{
Auxiliar function of genArise GUI.
}
\usage{
back.gui(envir)
}
\arguments{
  \item{envir}{Environment where are the project variables}
}
\value{
  tkwidget
  }
\keyword{IO}
