\name{note}
\alias{note}
\title{note}
\description{
Call a editor for note about actual experiment
}
\usage{
note(envir)
}
\arguments{
\item{envir}{Environment where are the experiment variables}
}
\keyword{arith}