\name{help}
\alias{help}
\title{Help of genArise}
\description{
  Display the help of genArise in the GUI. This is just a function for the GUI, and can not be
  used in the command line.
}
\usage{
help()
}
\keyword{documentation}