\name{WT.dataset}
\alias{WT.dataset}
\title{Microarray from the IFC}
\description{
This data set is a Microarray from the IFC.
}
\usage{data(WT.dataset)}
\format{A vector containing 4036 observations.}
\examples{
data(WT.dataset)
Zscore.plot(WT.dataset)
}
\keyword{datasets}
